@@ -1,4 +1,4 @@
-use super::common::{ImmutableString, Range};
+use super::common::{ImmutableString, Range, Ranged};
 
 /// A token found while scanning.
 #[derive(Debug, PartialEq, Clone)]
@@ -22,3 +22,9 @@ pub struct TokenAndRange {
     pub range: Range,
     pub token: Token,
 }
+
+impl Ranged for TokenAndRange {
+    fn range(&self) -> &Range {
+        &self.range
+    }
+}
